Examples
========

This page will document examples of using the packabe to send a message from the client, receive it on the server, take
an action, and send boht a multicast and omni-cast message in response